@@ -1,7 +1,7 @@
-__version__ = "1.0"
-
-from .core import App, Output, Input, get_nbchannels, get_pixel_type
+# -*- coding: utf-8 -*-
+__version__ = "1.2.2"
 
 from .apps import *
-
+from .core import App, Output, Input, get_nbchannels, get_pixel_type
 from .functions import *
+from .tools import logger
